summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJason Noguchi <jnoguchi@google.com>2013-02-21 04:33:47 +0000
committerAndroid (Google) Code Review <android-gerrit@google.com>2013-02-21 04:33:47 +0000
commit181cc4198bdf8f608d75319dd8c3245cc31a8180 (patch)
treeed13a47f8701c35fa9743cd0cad6722ac79b3167
parent275ca8be28783b3e87410533766cb1c2ec61e068 (diff)
parent81d9773a9682e19b671e586f34a6a55cdae7fe9e (diff)
downloadandroid_packages_apps_Snap-181cc4198bdf8f608d75319dd8c3245cc31a8180.tar.gz
android_packages_apps_Snap-181cc4198bdf8f608d75319dd8c3245cc31a8180.tar.bz2
android_packages_apps_Snap-181cc4198bdf8f608d75319dd8c3245cc31a8180.zip
Merge "Scaling down the stress test defaults iteration counts to some base level. For true stress testing, need to pass arguments to scale these back up to 100. Also, temporarily removing SwitchPreview test which needs updating and currently would block other tests in stress suite." into gb-ub-photos-bryce
-rwxr-xr-xtests/src/com/android/gallery3d/StressTests.java2
-rwxr-xr-xtests/src/com/android/gallery3d/stress/CameraStressTestRunner.java4
2 files changed, 3 insertions, 3 deletions
diff --git a/tests/src/com/android/gallery3d/StressTests.java b/tests/src/com/android/gallery3d/StressTests.java
index 32eefdcec..b991e9e8d 100755
--- a/tests/src/com/android/gallery3d/StressTests.java
+++ b/tests/src/com/android/gallery3d/StressTests.java
@@ -41,7 +41,7 @@ public class StressTests extends TestSuite {
result.addTestSuite(CameraLatency.class);
result.addTestSuite(CameraStartUp.class);
result.addTestSuite(ImageCapture.class);
- result.addTestSuite(SwitchPreview.class);
+// result.addTestSuite(SwitchPreview.class);
return result;
}
}
diff --git a/tests/src/com/android/gallery3d/stress/CameraStressTestRunner.java b/tests/src/com/android/gallery3d/stress/CameraStressTestRunner.java
index 57ae69125..d3fb10dad 100755
--- a/tests/src/com/android/gallery3d/stress/CameraStressTestRunner.java
+++ b/tests/src/com/android/gallery3d/stress/CameraStressTestRunner.java
@@ -25,8 +25,8 @@ public class CameraStressTestRunner extends InstrumentationTestRunner {
// Default recorder settings
public static int mVideoDuration = 20000; // set default to 20 seconds
- public static int mVideoIterations = 100; // set default to 100 videos
- public static int mImageIterations = 100; // set default to 100 images
+ public static int mVideoIterations = 1; // set default to 1 video
+ public static int mImageIterations = 10; // set default to 10 images
@Override
public TestSuite getAllTests() {